DAT programName byte "GraphRgbDemo150228c", 0 ' This will let me know what program is loaded in the Prop.
CON
{{
  ******* Public Notes *******

  Written By: Duane Degn
  Initial Release: June 2013
  MIT License (Use anyway you want but give me credit.)
  
  This is a program to light RGB LEDs using '595 shift registers.   
  Make sure and use current limiting resistors on your LEDs.
  

}}
{
  ******* Private Notes *******
 
  150228a Change name from "Led3ByteColor130619a" to "GraphRgbDemo150228a".
  Change to parent object.
  
} 
CON


  _CLKMODE = XTAL1 + PLL16X                             ' use crystal x 16
  _XINFREQ = 5_000_000                                  ' 5 MHz cyrstal (sys clock = 80 MHz)

  
  CLK_FREQ = ((_clkmode - xtal1) >> 6) * _xinfreq
  MS_001   = CLK_FREQ / 1_000
  US_001   = CLK_FREQ / 1_000_000

  
  
  ' Pin Assignments
  ' Shift Registers
  SHIFT_DATA = 16
  SHIFT_CLOCK = 27 
  SHIFT_LATCH = 15       

  ' Anode Control
  FIRST_ANODE_PIN = 0           ' The seven pins after FIRST_ANODE_PIN will also be used
                                ' for anode control. 

  EVENT_DETECTOR = 26
  STACK_SIZE = 100
  
  BAUD = 115_200
 
  TEST_CHARACTER = "s"
  ADVANCE_COLOMN_CHARACTER = 13
  INCREASE_BRIGHTNESS_CHARACTER = "+"
  DECREASE_BRIGHTNESS_CHARACTER = "-"
                                                                                                                                                           
VAR

  long eventStack[STACK_SIZE]
  long ledStackPtr, eventCount
  
  byte displayBuffer[Led#MAX_ALLOWED_DISPLAY_BYTES]

OBJ

  Pst : "Parallax Serial Terminal"                      ' uses 1 cog
  Led : "GraphRgb150228c"                               ' uses 2 cogs
    
PUB Setup | localIndex, localCharacter, count, colorIndex1, colorIndex2, colorIndex3
'' Total of four cogs used by this program.
     
  
  Pst.Start(BAUD) ' starts 1 cog
  
  ledStackPtr := Led.Start(SHIFT_DATA, SHIFT_CLOCK, SHIFT_LATCH, FIRST_ANODE_PIN, {
  } @eventCount, @pixel0, @displayBuffer) ' starts 2 cogs

  waitcnt(clkfreq * 3 + cnt) 
  Pst.Clear
  Pst.Home
 
  Pst.str(string(13, "8 x 8 RGB LED Array Graphing Demo"))

  Pst.str(string(13, "name of top object = "))
  Pst.str(@programName)
  
  cognew(EventDetect(EVENT_DETECTOR), @eventStack)
 
  
  waitcnt(clkfreq / 4 + cnt)
 
  MainLoop

PUB MainLoop | previousEventCount

  previousEventCount := eventCount
  repeat
    result := Pst.RxCount                                                                            
    if result
      CheckInput
    if eventCount <> previousEventCount
      previousEventCount := eventCount 
      Pst.str(string(13, "eventCount = ")) 
      Pst.Dec(previousEventCount)
      
PUB CheckInput  

  result := Pst.CharIn
  
  case result
    TEST_CHARACTER:
      eventCount++
    ADVANCE_COLOMN_CHARACTER:
      Led.ForceColumn  
    INCREASE_BRIGHTNESS_CHARACTER:
      if brightness < 255
        brightness++
        Led.ChangeBrightness(brightness)
      Pst.str(string(13, "brightness = ")) 
      Pst.Dec(brightness)  
    DECREASE_BRIGHTNESS_CHARACTER:
      if brightness
        brightness--
        Led.ChangeBrightness(brightness)
      Pst.str(string(13, "brightness = ")) 
      Pst.Dec(brightness)
      
PRI EventDetect(detectionPin) : newDetect | oldDetect

  oldDetect := 1 ' watch for pin to go low
  repeat
    repeat
      newDetect := ina[detectionPin]
    while newDetect == oldDetect
    oldDetect := newDetect
    if newDetect == 0 ' active low
      eventCount++
         
DAT
 
columnColors                'red  green, blue
pixel0                  byte $00, $FF, $00  ' green (on the bottom)
pixel1                  byte $00, $FF, $00
pixel2                  byte $FF, $6F, $00  ' yellow
pixel3                  byte $FF, $6F, $00
pixel4                  byte $FF, $2F, $00  ' orange
pixel5                  byte $FF, $2F, $00
pixel6                  byte $FF, $00, $00
pixel7                  byte $FF, $00, $00  ' red at the top 

brightness              byte Led#DEFAULT_BRIGHTNESS
                                                                                           